"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "DataInputType", {
  enumerable: true,
  get: function () {
    return _types.DataInputType;
  }
});
Object.defineProperty(exports, "OCREvent", {
  enumerable: true,
  get: function () {
    return _types.OCREvent;
  }
});
Object.defineProperty(exports, "OCROptions", {
  enumerable: true,
  get: function () {
    return _types.OCROptions;
  }
});
Object.defineProperty(exports, "OcrEngineMode", {
  enumerable: true,
  get: function () {
    return _types.OcrEngineMode;
  }
});
Object.defineProperty(exports, "PageSegMode", {
  enumerable: true,
  get: function () {
    return _types.PageSegMode;
  }
});
exports.useOCREventListener = exports.getText = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _types = require("./types");
const LINKING_ERROR = `The package 'rn-ocr-lib' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';
const RnOcrLib = _reactNative.NativeModules.RnOcrLib ? _reactNative.NativeModules.RnOcrLib : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
const defaultOptions = {
  pageSegMode: _types.PageSegMode.PSM_SINGLE_BLOCK,
  ocrEngineMode: _types.OcrEngineMode.FAST,
  lang: ['eng']
};
const tessLangMap = _types.tesseractSupportedLanguages.reduce((acc, o) => ({
  ...acc,
  [o]: true
}), {});
const getText = (data, inputType, options) => {
  const finalOptions = {
    ...defaultOptions,
    ...options
  };
  if (_reactNative.Platform.OS === 'ios') {
    finalOptions.lang = (finalOptions.lang || []).reduce((acc, o) => {
      if (_types.iOSLangMapping[o]) {
        acc.push(_types.iOSLangMapping[o] || '');
      }
      return acc;
    }, []);
  } else {
    finalOptions.lang = finalOptions.lang.filter(o => tessLangMap[o]);
  }
  if (!finalOptions.lang.length) {
    throw new Error('Unsupported language');
  }
  if (inputType === _types.DataInputType.base64) {
    data = data.replace(new RegExp('^data:image/[^;]*;base64,?', 'gi'), '');
  }
  RnOcrLib.getText(data, inputType, finalOptions);
};
exports.getText = getText;
const useOCREventListener = cb => {
  (0, _react.useEffect)(() => {
    if (!cb) return;
    const eventEmitter = new _reactNative.NativeEventEmitter(_reactNative.NativeModules.RnOcrLib);
    eventEmitter.addListener(_types.OCREvent.FINISHED, event => {
      cb(_types.OCREvent.FINISHED, event);
    });
    eventEmitter.addListener(_types.OCREvent.PROGRESS, event => {
      cb(_types.OCREvent.PROGRESS, event);
    });
    eventEmitter.addListener(_types.OCREvent.ERROR, event => {
      cb(_types.OCREvent.ERROR, event);
    });
    return () => {
      eventEmitter.removeAllListeners(_types.OCREvent.FINISHED);
      eventEmitter.removeAllListeners(_types.OCREvent.PROGRESS);
      eventEmitter.removeAllListeners(_types.OCREvent.ERROR);
    };
  }, [cb]);
};
exports.useOCREventListener = useOCREventListener;
//# sourceMappingURL=index.js.map